==> suir-component-mapper-3.11.0.tgz: package/esm/time-picker/time-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormField from '../form-field/form-field';

var TimePicker = function TimePicker(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelpertextProps = _useFieldApi.HelpertextProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "isReadOnly", "isDisabled", "isRequired", "helperText", "validateOnMount", "meta", "FormFieldGridProps", "HelpertextProps"]);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    required: isRequired,
    readOnly: isReadOnly,
    disabled: isDisabled,
    error: invalid && {
      content: meta.error || meta.submitError
    },
    control: function control(props) {
      return /*#__PURE__*/React.createElement("input", _extends({}, props, {
        readOnly: isReadOnly,
        disabled: isDisabled
      }));
    }
  }, input, rest, {
    type: "time"
  })));
};

TimePicker.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  locale: PropTypes.string,
  description: PropTypes.node,

  /** Sub component customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
TimePicker.defaultProps = {
  FormFieldGridProps: {},
  HelpertextProps: {}
};
export default TimePicker;

==> suir-component-mapper-3.16.0.tgz: package/esm/time-picker/time-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "isRequired", "helperText", "validateOnMount", "meta", "FormFieldGridProps", "HelpertextProps"];
import React from 'react';
import PropTypes from 'prop-types';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormField from '../form-field/form-field';

var TimePicker = function TimePicker(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelpertextProps = _useFieldApi.HelpertextProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    required: isRequired,
    readOnly: isReadOnly,
    disabled: isDisabled,
    error: invalid && {
      content: meta.error || meta.submitError
    },
    control: function control(props) {
      return /*#__PURE__*/React.createElement("input", _extends({}, props, {
        readOnly: isReadOnly,
        disabled: isDisabled
      }));
    }
  }, input, rest, {
    type: "time"
  })));
};

TimePicker.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  locale: PropTypes.string,
  description: PropTypes.node,

  /** Sub component customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
TimePicker.defaultProps = {
  FormFieldGridProps: {},
  HelpertextProps: {}
};
export default TimePicker;
